@@ -17,6 +17,7 @@ from typing import Any, Dict, List, Sequence
 
 from .literals import (
     AccessControlRuleEffectType,
+    DnsRecordVerificationStatusType,
     EntityStateType,
     FolderNameType,
     MailboxExportJobStateType,
@@ -64,6 +65,7 @@ __all__ = (
     "DeleteRetentionPolicyRequestRequestTypeDef",
     "DeleteUserRequestRequestTypeDef",
     "DeregisterFromWorkMailRequestRequestTypeDef",
+    "DeregisterMailDomainRequestRequestTypeDef",
     "DescribeGroupRequestRequestTypeDef",
     "DescribeGroupResponseTypeDef",
     "DescribeInboundDmarcSettingsRequestRequestTypeDef",
@@ -78,12 +80,15 @@ __all__ = (
     "DescribeUserResponseTypeDef",
     "DisassociateDelegateFromResourceRequestRequestTypeDef",
     "DisassociateMemberFromGroupRequestRequestTypeDef",
+    "DnsRecordTypeDef",
     "DomainTypeDef",
     "FolderConfigurationTypeDef",
     "GetAccessControlEffectRequestRequestTypeDef",
     "GetAccessControlEffectResponseTypeDef",
     "GetDefaultRetentionPolicyRequestRequestTypeDef",
     "GetDefaultRetentionPolicyResponseTypeDef",
+    "GetMailDomainRequestRequestTypeDef",
+    "GetMailDomainResponseTypeDef",
     "GetMailboxDetailsRequestRequestTypeDef",
     "GetMailboxDetailsResponseTypeDef",
     "GetMobileDeviceAccessEffectRequestRequestTypeDef",
@@ -99,6 +104,8 @@ __all__ = (
     "ListGroupMembersResponseTypeDef",
     "ListGroupsRequestRequestTypeDef",
     "ListGroupsResponseTypeDef",
+    "ListMailDomainsRequestRequestTypeDef",
+    "ListMailDomainsResponseTypeDef",
     "ListMailboxExportJobsRequestRequestTypeDef",
     "ListMailboxExportJobsResponseTypeDef",
     "ListMailboxPermissionsRequestRequestTypeDef",
@@ -117,6 +124,7 @@ __all__ = (
     "ListTagsForResourceResponseTypeDef",
     "ListUsersRequestRequestTypeDef",
     "ListUsersResponseTypeDef",
+    "MailDomainSummaryTypeDef",
     "MailboxExportJobTypeDef",
     "MemberTypeDef",
     "MobileDeviceAccessMatchedRuleTypeDef",
@@ -130,6 +138,7 @@ __all__ = (
     "PutMailboxPermissionsRequestRequestTypeDef",
     "PutMobileDeviceAccessOverrideRequestRequestTypeDef",
     "PutRetentionPolicyRequestRequestTypeDef",
+    "RegisterMailDomainRequestRequestTypeDef",
     "RegisterToWorkMailRequestRequestTypeDef",
     "ResetPasswordRequestRequestTypeDef",
     "ResourceTypeDef",
@@ -139,6 +148,7 @@ __all__ = (
     "TagResourceRequestRequestTypeDef",
     "TagTypeDef",
     "UntagResourceRequestRequestTypeDef",
+    "UpdateDefaultMailDomainRequestRequestTypeDef",
     "UpdateMailboxQuotaRequestRequestTypeDef",
     "UpdateMobileDeviceAccessRuleRequestRequestTypeDef",
     "UpdatePrimaryEmailAddressRequestRequestTypeDef",
@@ -459,6 +469,14 @@ DeregisterFromWorkMailRequestRequestTypeDef = TypedDict(
     },
 )
 
+DeregisterMailDomainRequestRequestTypeDef = TypedDict(
+    "DeregisterMailDomainRequestRequestTypeDef",
+    {
+        "OrganizationId": str,
+        "DomainName": str,
+    },
+)
+
 DescribeGroupRequestRequestTypeDef = TypedDict(
     "DescribeGroupRequestRequestTypeDef",
     {
@@ -609,6 +627,16 @@ DisassociateMemberFromGroupRequestRequestTypeDef = TypedDict(
     },
 )
 
+DnsRecordTypeDef = TypedDict(
+    "DnsRecordTypeDef",
+    {
+        "Type": str,
+        "Hostname": str,
+        "Value": str,
+    },
+    total=False,
+)
+
 DomainTypeDef = TypedDict(
     "DomainTypeDef",
     {
@@ -677,6 +705,26 @@ GetDefaultRetentionPolicyResponseTypeDef = TypedDict(
     },
 )
 
+GetMailDomainRequestRequestTypeDef = TypedDict(
+    "GetMailDomainRequestRequestTypeDef",
+    {
+        "OrganizationId": str,
+        "DomainName": str,
+    },
+)
+
+GetMailDomainResponseTypeDef = TypedDict(
+    "GetMailDomainResponseTypeDef",
+    {
+        "Records": List["DnsRecordTypeDef"],
+        "IsTestDomain": bool,
+        "IsDefault": bool,
+        "OwnershipVerificationStatus": DnsRecordVerificationStatusType,
+        "DkimVerificationStatus": DnsRecordVerificationStatusType,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 GetMailboxDetailsRequestRequestTypeDef = TypedDict(
     "GetMailboxDetailsRequestRequestTypeDef",
     {
@@ -873,6 +921,37 @@ ListGroupsResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredListMailDomainsRequestRequestTypeDef = TypedDict(
+    "_RequiredListMailDomainsRequestRequestTypeDef",
+    {
+        "OrganizationId": str,
+    },
+)
+_OptionalListMailDomainsRequestRequestTypeDef = TypedDict(
+    "_OptionalListMailDomainsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListMailDomainsRequestRequestTypeDef(
+    _RequiredListMailDomainsRequestRequestTypeDef, _OptionalListMailDomainsRequestRequestTypeDef
+):
+    pass
+
+
+ListMailDomainsResponseTypeDef = TypedDict(
+    "ListMailDomainsResponseTypeDef",
+    {
+        "MailDomains": List["MailDomainSummaryTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredListMailboxExportJobsRequestRequestTypeDef = TypedDict(
     "_RequiredListMailboxExportJobsRequestRequestTypeDef",
     {
@@ -1115,6 +1194,15 @@ ListUsersResponseTypeDef = TypedDict(
     },
 )
 
+MailDomainSummaryTypeDef = TypedDict(
+    "MailDomainSummaryTypeDef",
+    {
+        "DomainName": str,
+        "DefaultDomain": bool,
+    },
+    total=False,
+)
+
 MailboxExportJobTypeDef = TypedDict(
     "MailboxExportJobTypeDef",
     {
@@ -1316,6 +1404,29 @@ class PutRetentionPolicyRequestRequestTypeDef(
     pass
 
 
+_RequiredRegisterMailDomainRequestRequestTypeDef = TypedDict(
+    "_RequiredRegisterMailDomainRequestRequestTypeDef",
+    {
+        "OrganizationId": str,
+        "DomainName": str,
+    },
+)
+_OptionalRegisterMailDomainRequestRequestTypeDef = TypedDict(
+    "_OptionalRegisterMailDomainRequestRequestTypeDef",
+    {
+        "ClientToken": str,
+    },
+    total=False,
+)
+
+
+class RegisterMailDomainRequestRequestTypeDef(
+    _RequiredRegisterMailDomainRequestRequestTypeDef,
+    _OptionalRegisterMailDomainRequestRequestTypeDef,
+):
+    pass
+
+
 RegisterToWorkMailRequestRequestTypeDef = TypedDict(
     "RegisterToWorkMailRequestRequestTypeDef",
     {
@@ -1419,6 +1530,14 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
+UpdateDefaultMailDomainRequestRequestTypeDef = TypedDict(
+    "UpdateDefaultMailDomainRequestRequestTypeDef",
+    {
+        "OrganizationId": str,
+        "DomainName": str,
+    },
+)
+
 UpdateMailboxQuotaRequestRequestTypeDef = TypedDict(
     "UpdateMailboxQuotaRequestRequestTypeDef",
     {
